# Crypno Python Package

---

1. Register In [Crypno](https://crypno.ir).
2. use this command to install the package:
    ```
    pip install crypno
    ```
3. Use The Available Methods Introduced In The [Crypno Docs](https://crypno.ir/docs).